package kr.co.uplus.ez.api.stats;

import kr.co.uplus.ez.api.stats.dto.*;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface StatsMapper {
	/**  */
    List<MonthList> selectMonStatList(MonthListReqDto monthListReqDto);
    /**  */
    List<DayList> selectDayStatList(DayListReqDto dayListReqDto);
    /** 월별톨계 목록 조회 */
    List<BsnmMonthList> selectCustMstatList(BsnmMonthListReqDto bsnmMonthListReqDto);
    /** 일별통계 목록 조회 */
    List<BsnmDayList> selectCustDstatList(BsnmDayListReqDto bsnmDayListReqDto);
    /** 월별통계 카운트 조회 */
	int selectCustMstatListTotalCnt(BsnmMonthListReqDto bsnmMonthListReqDto);
	/** 일별통계 카운트 조회 */
	int selectCustDstatListTotalCnt(BsnmDayListReqDto bsnmDayListReqDto);

    /** 월별톨계 Excel 목록 조회 */
    List<BsnmMonthList> selectCustMstatExcelList(BsnmMonthListExcelReqDto bsnmMonthListExcelReqDto);
    /** 일별통계 Excel 목록 조회 */
    List<BsnmDayList> selectCustDstatExcelList(BsnmDayListExcelReqDto bsnmDayListExcelReqDto);

}
